import type { Metadata } from './metadata.types';
/**
 * A Metadata cache definition
 * @public
 */
export interface MetadataCache {
    /**
     * A map of cached metadata, with resource names as keys and metadata as values.
     * @public
     */
    cachedMetadata: Map<string, Metadata>;
    /**
     * Returns the metadata for the specified resource name.
     * @public
     * @param resourceName - The name of the resource.
     * @returns The metadata for the specified resource name.
     */
    getMetadataFor(resourceName: string): Metadata;
    /**
     * Returns true if metadata exists for the specified resource name, otherwise false.
     * @public
     * @param resourceName - The name of the resource.
     * @returns True if metadata exists for the specified resource name, otherwise false.
     */
    hasMetadataFor(resourceName: string): boolean;
    /**
     * Sets the metadata for the specified resource name.
     * @public
     * @param resourceName - The name of the resource.
     * @param metadata - The metadata to set.
     */
    setMetadataFor(resourceName: string, metadata: Metadata): void;
}
/**
 * The DI token for the MetadataService interface.
 * @internal
 */
export declare const MetadataCache: import("@microsoft/fast-foundation").InterfaceSymbol<MetadataCache>;
//# sourceMappingURL=metadata.d.ts.map